@@ -19,7 +19,6 @@ class NormalNormalKnownVar:
         self.known_var = known_var
 
     def update(self, data):
-        data = np.log(data)
         var = np.var(data)
         mean = np.mean(data)
         n = len(data)
@@ -28,10 +27,10 @@ class NormalNormalKnownVar:
                                     1.0 / denom)
 
     def pdf(self, x):
-        return stats.norm.pdf(x, self.mean, self.var)
+        return stats.norm.pdf(x, self.mean, np.sqrt(self.var))
 
     def cdf(self, x):
-        return stats.norm.cdf(x, self.mean, self.var)
+        return stats.norm.cdf(x, self.mean, np.sqrt(self.var))
 
     def posterior(self, l, u):
         if l > u:
@@ -40,13 +39,16 @@ class NormalNormalKnownVar:
 
     def plot(self, l=0.0, u=1.0):
         x = np.linspace(u, l, 1001)
-        y = stats.norm.pdf(x, self.mean, self.var)
+        y = stats.norm.pdf(x, self.mean, np.sqrt(self.var))
         y = y / y.sum()
         plt.plot(x, y)
         plt.xlim((l, u))
 
     def predict(self, x):
-        return stats.norm.cdf(x, self.mean, self.var + self.known_var)
+        return stats.norm.cdf(x, self.mean, np.sqrt(self.var + self.known_var))
+
+    def sample(self):
+        return np.random.normal(self.mean, np.sqrt(self.var + self.known_var))
 
 
 class NormalLogNormalKnownVar(NormalNormalKnownVar):
@@ -61,3 +63,6 @@ class NormalLogNormalKnownVar(NormalNormalKnownVar):
 
     def predict(self, x):
         raise NotImplemented("No posterior predictive")
+
+    def sample(self):
+        return np.log(np.random.normal(self.mean, np.sqrt(self.var + self.known_var)))
